unit UMisc;

Interface

Uses
  Registry,
	Classes,
  Dialogs,
  IniFiles,
  Windows,
  SysUtils;

Const
	CRLF = Chr(13) + Chr(10);
	//messages
  MSGFILEEMPTY = 1;
  MSGFILENOTFOUND = 2;
  MSGFILENOTOPEN = 3;
  DEFBACKUPEXT = 4;
	MSGINPREP = 5;
  MSGTEMPLATETOCLIP = 6;
  MSGTEXTNOTFOUND = 7;
  MSGFILESAVEAS = 8;
	MSGNOFILE = 9;
  MSGDEFFILE = 10;
  MSGNEWTEMPLATE = 11;
  MSGWINDOWNOTFOUND = 12;
  MSGNOWINDOWS = 13;
	MSGTEMPLATETOWINDOW = 14;
	MSGFILEREADONLY = 15;
	MSGAPPRUNNING = 16;

Type
	tAppMsg = (InfoMsg, ErrorMsg, WarningMsg);

Function AppStr(sIniFile : String; nMsgNo : Integer; sPar1 : String; sPar2 : String) : String;
Function AppMsg(sIniFile : String; tDlgType : TMsgDlgType; nMsgNo : Integer; sPar1 : String; sPar2 : String) : String;
Function AppDlg(sIniFile : String; nMsgNo : Integer; sPar1 : String; sPar2 : String) : Word;
Function Int2Str(I: Longint): string;
Function Bool2Str(B: Boolean): string;
Function Str2Int(sStr : String) : LongInt;
Function Str2Real(sStr : String) : Extended;
Function IsStringEmpty(const pMyParameter: PChar): Integer;stdcall;export;
Function RegGetValue(sKey : String; sValue : String) : String;
Function RegSetValue(sKey : String; sName : String; sValue : String): Integer;
Function IniGetValue(sTheIniFile : String;sIniSection : String;sStringName : String;sDefaultString : String ) : String;
Function IniSetValue(sTheIniFile : String;sIniSection : String;sStringName : String;sStringValue : String): Integer;
Function IniDelKey(sTheIniFile : String;sIniSection : String;sStringName : String): Integer;
Function IniDelSection(sTheIniFile : String;sIniSection : String ) : Integer;
Function GetDayOfWeek(sDate : string) : string;
Function CheckFile(sFilename : String) : Boolean;
Function CheckIni(sIniFile : String): String;
Procedure PostKeyEx32( key: Word; Const shift: TShiftState; specialkey:
Boolean );

Implementation

//
//Messages
//

Function AppStr(sIniFile : String; nMsgNo : Integer; sPar1 : String; sPar2 : String) : String;
//retrieves a string from the messages section of the lng-file
//Parameter:
//nMsgNo = messages number to be retrieved out of the languagefile
//sPar1 = parameter 1
//sPar2 = parameter 2
var
	sMsg : String;
begin
	AppStr := '';
	if FileExists(sIniFile) = False then
		begin
			MessageDlg(Format('Languagefile ''%s'' not found!', [sIniFile]), mtError, [mbOk], 0);
			Exit;
    end;
	sMsg := IniGetValue(sIniFile, 'Messages', Int2Str(nMsgNo), '');
	AppStr := Format(sMsg, [sPar1, sPar2]);
end;

Function AppMsg(sIniFile : String; tDlgType : TMsgDlgType; nMsgNo : Integer; sPar1 : String; sPar2 : String) : String;
//display a message
//Parameter:
//tDlgType = type of the message
//nMsgNo = messages number to be retrieved out of the languagefile
//sPar1 = parameter 1
//sPar2 = parameter 2
var
	sMsg : String;
begin
	if FileExists(sIniFile) = False then
		begin
			MessageDlg(Format('Languagefile ''%s'' not found!', [sIniFile]), mtError, [mbOk], 0);
			AppMsg := '';
			Exit;
    end;
	sMsg := IniGetValue(sIniFile, 'Messages', Int2Str(nMsgNo), '');
	If sMsg = '' Then
  	Begin
			AppMsg := '';
    	Exit;
    End;
	MessageDlg(Format(sMsg, [sPar1, sPar2]), tDlgType, [mbOk], 0);
	AppMsg := Format(sMsg, [sPar1, sPar2]);
end;

Function AppDlg(sIniFile : String; nMsgNo : Integer; sPar1 : String; sPar2 : String) : Word;
//dialog message
//Parameter:
//nMsgNo = messages number to be retrieved out of the languagefile
//sPar1 = parameter 1
//sPar2 = parameter 2
var
	sMsg : String;
begin
	if FileExists(sIniFile) = False then
		begin
			MessageDlg(Format('Languagefile ''%s'' not found!', [sIniFile]), mtError, [mbOk], 0);
			AppDlg := 0;
			Exit;
    end;
	sMsg := IniGetValue(sIniFile, 'Messages', Int2Str(nMsgNo), '');
	If sMsg = '' Then
  	Begin
			AppDlg := 0;
    	Exit;
    End;
	AppDlg := MessageDlg(Format(sMsg, [sPar1, sPar2]), mtConfirmation, [mbYes, mbNo], 0);
end;

//
//Conversion
//
Function Int2Str(I: Longint): string;
//Beliebigen Integer-Typ in String konvertieren
var
  S: string;
begin
  Str(I, S);
  Result:= S;
end;

Function Bool2Str(B: Boolean): string;
//Boolean-Typ in String konvertieren
var
  S: string;
  I: Integer;
begin
	I := 0;
	//
	If B = True Then I := 1;
  Str(I, S);
	//
	S := 'False';
	If B = True Then S := 'True';
  Result:= S;
end;

Function Str2Int(sStr : String) : LongInt;
//Beliebigen String in Integer-Typ konvertieren
var Code : Integer;
var MyVal : LongInt;
begin
  Val(sStr, MyVal, Code);
  Str2Int := MyVal;
end;

Function Str2Real(sStr : String) : Extended;
//Beliebigen String in Real-Typ konvertieren
var Code : Integer;
var MyVal : Extended;
begin
  Val(sStr, MyVal, Code);
  Str2Real := MyVal;
end;

Function IsStringEmpty(const pMyParameter: PChar): Integer;stdcall;export;
//Test on empty string
Begin
	If StrLen(pMyParameter) = 0 then
		Result := 1
	Else
		Result := 0;
End;

Function RegGetValue(sKey : String; sValue : String) : String;
//Get a value out of the windows registry
Var
  Registry: TRegistry;
  sTmp : String;
Begin
  Registry := TRegistry.Create;
  try
    Registry.RootKey := HKEY_LOCAL_MACHINE;
    Registry.OpenKey(sKey, False);
    sTmp := Registry.ReadString(sValue);
  finally
    Registry.CloseKey;
    Registry.Free;
  End;
	Result := sTmp;
End;

Function RegSetValue(sKey : String; sName : String; sValue : String): Integer;
//sets a value in the registry
Var
  Registry: TRegistry;
  nRT : Integer;
Begin
  nRT := 0;
  Registry := TRegistry.Create;
  try
    Registry.RootKey := HKEY_LOCAL_MACHINE;
    If Registry.OpenKey(sKey, True) Then
      Begin
        Registry.WriteString(sName, sValue);
        nRT := 1;
      End
  finally
    Registry.CloseKey;
    Registry.Free;
  end;
  Result := nRT;
End;

Function IniGetValue(
  sTheIniFile : String;
  sIniSection : String;
  sStringName : String;
  sDefaultString : String ) : String;
//get an ini string
Var
  TheIni : TIniFile;
  sTmp : String;
Begin
  //ShowMessage(pTheIniFile + '#' + pIniSection + '#' + pStringName);
  TheIni := TIniFile.Create(sTheIniFile);
  Try
    sTmp := TheIni.ReadString(sIniSection, sStringName, sDefaultString);
    If sTmp = '' Then
    Begin
      sTmp := sDefaultString;
    End;
  Finally
    TheIni.Free;
  End;
	Result := sTmp;
End;

Function IniSetValue(
  sTheIniFile : String;
  sIniSection : String;
  sStringName : String;
  sStringValue  : String): Integer;
//set an ini string
Var
  TheIni                : TIniFile;
Begin
  TheIni                := TIniFile.Create(sTheIniFile);
  Try
    Try
      TheIni.WriteString(sIniSection, sStringName, sStringValue);
      Result := 1;
    Except
      Result := 0;
    End;
  Finally
    TheIni.UpdateFile;
    TheIni.Free;
  End;
End;

Function IniDelKey(
  sTheIniFile : String;
  sIniSection : String;
  sStringName : String): Integer;
//set an ini string
Var
  TheIni                : TIniFile;
Begin
  TheIni                := TIniFile.Create(sTheIniFile);
  Try
    Try
      TheIni.DeleteKey(sIniSection, sStringName);
      Result := 1;
    Except
      Result := 0;
    End;
  Finally
    TheIni.UpdateFile;
    TheIni.Free;
  End;
End;

Function IniDelSection(
  sTheIniFile : String;
  sIniSection : String ) : Integer;
//deletes an section
Var
  TheIni                : TIniFile;
Begin
  TheIni                := TIniFile.Create(sTheIniFile);
  Try
    Try
      TheIni.EraseSection(sIniSection);
      Result := 1;
    Except
      Result := 0;
    End;
  Finally
    TheIni.UpdateFile;
    TheIni.Free;
  End;
End;

Function GetDayOfWeek(sDate : string) : string;
var
  ADate: TDateTime;
  days: array[1..7] of string;
begin
  days[1] := 'Sonntag';
  days[2] := 'Montag';
  days[3] := 'Dienstag';
  days[4] := 'Mittwoch';
  days[5] := 'Donnerstag';
  days[6] := 'Freitag';
  days[7] := 'Samstag';
  ADate := StrToDate(sDate);
  GetDayOfWeek := days[DayOfWeek(ADate)];
end;

Function CheckFile(sFilename : String) : Boolean;
Begin
	if FileExists(sFilename) = False then
		begin
			Result := False;
      Exit;
    end;
	Result := True;
End;

Function CheckIni(sIniFile : String) : String;
Begin
	//sIniFile :='c:\daten\vdp\vdp3\dlldev\litmsg\litmsg.ini';
  //ini file check
  If (Pos('\', sIniFile) = 0) Or (Pos(':', sIniFile) = 0) then
  	Begin
		  sIniFile := GetCurrentDir + '\' + sIniFile;
    End;
  If CheckFile(sIniFile) = False then
    Begin
      sIniFile := '';
    End;
  //MessageDlg('Ini-Datei "' + sIniFile + '" ', mtError, [mbOk], 0);
	Result := sIniFile;
End;

//
//
//

Procedure PostKeyEx32(
	key: Word;
  Const shift: TShiftState;
  specialkey: Boolean );
{************************************************************
* Procedure PostKeyEx32
*
* Parameters:
* key : virtual keycode of the key to send. For printable
* keys this is simply the ANSI code (Ord(character)).
* shift : state of the modifier keys. This is a set, so you
* can set several of these keys (shift, control, alt,
* mouse buttons) in tandem. The TShiftState type is
* declared in the Classes Unit.
* specialkey: normally this should be False. Set it to True to
* specify a key on the numeric keypad, for example.
* Description:
* Uses keybd_event to manufacture a series of key events matching
* the passed parameters. The events go to the control with focus.
* Note that for characters key is always the upper-case version of
* the character. Sending without any modifier keys will result in
* a lower-case character, sending it with [ssShift] will result
* in an upper-case character!
*Created: 17.7.98 by P. Below
************************************************************}

Type
	TShiftKeyInfo = Record
	shift: Byte;
	vkey : Byte;
	End;
byteset = Set of 0..7;
Const
	shiftkeys: Array [1..3] of TShiftKeyInfo =
	((shift: Ord(ssCtrl); vkey: VK_CONTROL ),
	(shift: Ord(ssShift); vkey: VK_SHIFT ),
	(shift: Ord(ssAlt); vkey: VK_MENU ));
Var
	flag: DWORD;
	bShift: ByteSet absolute shift;
	i: Integer;
Begin
For i := 1 To 3 Do Begin
If shiftkeys[i].shift In bShift Then
keybd_event( shiftkeys[i].vkey, MapVirtualKey(shiftkeys[i].vkey, 0), 0, 0);
End; { For }
If specialkey Then
flag := KEYEVENTF_EXTENDEDKEY
Else
flag := 0;

keybd_event( key, MapvirtualKey( key, 0 ), flag, 0 );
flag := flag or KEYEVENTF_KEYUP;
keybd_event( key, MapvirtualKey( key, 0 ), flag, 0 );

For i := 3 DownTo 1 Do Begin
If shiftkeys[i].shift In bShift Then
keybd_event( shiftkeys[i].vkey, MapVirtualKey(shiftkeys[i].vkey, 0),
KEYEVENTF_KEYUP, 0);
End; { For }
End; { PostKeyEx32 }


End.

